==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkHyperTree.java <==
// java wrapper for vtkHyperTree object
//

package vtk;
import vtk.*;

public class vtkHyperTree extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native long NewCursor_3();
  public vtkHyperTreeCursor NewCursor() {
    long temp = NewCursor_3();

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfLeaves_4();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_4(); }

  private native int GetNumberOfNodes_5();
  public int GetNumberOfNodes()
    { return GetNumberOfNodes_5(); }

  private native int GetNumberOfIndex_6();
  public int GetNumberOfIndex()
    { return GetNumberOfIndex_6(); }

  private native int GetBranchFactor_7();
  public int GetBranchFactor()
    { return GetBranchFactor_7(); }

  private native int GetDimension_8();
  public int GetDimension()
    { return GetDimension_8(); }

  private native void SetScale_9(double id0[]);
  public void SetScale(double id0[])
    { SetScale_9(id0); }

  private native void GetScale_10(double id0[]);
  public void GetScale(double id0[])
    { GetScale_10(id0); }

  private native double GetScale_11(int id0);
  public double GetScale(int id0)
    { return GetScale_11(id0); }

  private native int GetNumberOfLevels_12();
  public int GetNumberOfLevels()
    { return GetNumberOfLevels_12(); }

  private native void SubdivideLeaf_13(vtkHyperTreeCursor id0);
  public void SubdivideLeaf(vtkHyperTreeCursor id0)
    { SubdivideLeaf_13(id0); }

  private native int GetActualMemorySize_14();
  public int GetActualMemorySize()
    { return GetActualMemorySize_14(); }

  private native long CreateInstance_15(int id0,int id1);
  public vtkHyperTree CreateInstance(int id0,int id1) {
    long temp = CreateInstance_15(id0,id1);

    if (temp == 0) return null;
    return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGlobalIndexStart_16(int id0);
  public void SetGlobalIndexStart(int id0)
    { SetGlobalIndexStart_16(id0); }

  private native void SetGlobalIndexFromLocal_17(int id0,int id1);
  public void SetGlobalIndexFromLocal(int id0,int id1)
    { SetGlobalIndexFromLocal_17(id0,id1); }

  private native int GetGlobalIndexFromLocal_18(int id0);
  public int GetGlobalIndexFromLocal(int id0)
    { return GetGlobalIndexFromLocal_18(id0); }

  public vtkHyperTree() { super(); }

  public vtkHyperTree(long id) { super(id); }

}

==> vtk-8.0.1-4-armv7h.pkg.tar.xz: vtk/vtkHyperTree.java <==
// java wrapper for vtkHyperTree object
//

package vtk;
import vtk.*;

public class vtkHyperTree extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native long NewCursor_3();
  public vtkHyperTreeCursor NewCursor() {
    long temp = NewCursor_3();

    if (temp == 0) return null;
    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfLeaves_4();
  public int GetNumberOfLeaves()
    { return GetNumberOfLeaves_4(); }

  private native int GetNumberOfNodes_5();
  public int GetNumberOfNodes()
    { return GetNumberOfNodes_5(); }

  private native int GetNumberOfIndex_6();
  public int GetNumberOfIndex()
    { return GetNumberOfIndex_6(); }

  private native int GetBranchFactor_7();
  public int GetBranchFactor()
    { return GetBranchFactor_7(); }

  private native int GetDimension_8();
  public int GetDimension()
    { return GetDimension_8(); }

  private native void SetScale_9(double id0[]);
  public void SetScale(double id0[])
    { SetScale_9(id0); }

  private native void GetScale_10(double id0[]);
  public void GetScale(double id0[])
    { GetScale_10(id0); }

  private native double GetScale_11(int id0);
  public double GetScale(int id0)
    { return GetScale_11(id0); }

  private native int GetNumberOfLevels_12();
  public int GetNumberOfLevels()
    { return GetNumberOfLevels_12(); }

  private native void SubdivideLeaf_13(vtkHyperTreeCursor id0);
  public void SubdivideLeaf(vtkHyperTreeCursor id0)
    { SubdivideLeaf_13(id0); }

  private native int GetActualMemorySize_14();
  public int GetActualMemorySize()
    { return GetActualMemorySize_14(); }

  private native long CreateInstance_15(int id0,int id1);
  public vtkHyperTree CreateInstance(int id0,int id1) {
    long temp = CreateInstance_15(id0,id1);

    if (temp == 0) return null;
    return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGlobalIndexStart_16(int id0);
  public void SetGlobalIndexStart(int id0)
    { SetGlobalIndexStart_16(id0); }

  private native void SetGlobalIndexFromLocal_17(int id0,int id1);
  public void SetGlobalIndexFromLocal(int id0,int id1)
    { SetGlobalIndexFromLocal_17(id0,id1); }

  private native int GetGlobalIndexFromLocal_18(int id0);
  public int GetGlobalIndexFromLocal(int id0)
    { return GetGlobalIndexFromLocal_18(id0); }

  public vtkHyperTree() { super(); }

  public vtkHyperTree(long id) { super(id); }

}
